<!-- markdownlint-disable -->

<a href="..\..\qtstrap\utils\decorators.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `utils.decorators`





---

<a href="..\..\qtstrap\utils\decorators.py#L5"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `trace`

```python
trace(func)
```








---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
